/****************************************************************************
 *
 * Filename:    th03.h
 * Copyright:   Pico Technology Limited 1994-1998
 * Author:      Mike Green
 *              www.picotech.com
 * Description:
 * This header defines the interface to driver routines for the PICO TH-03.
 *
 * Revision Info: "file %n date %f revision %v"
 *                ""
 *
 ****************************************************************************/

/* Set up prefixes for the declarations...
 *  some adjustments may be required here to match your compiler
 */

#ifdef __cplusplus
#define PREF1 extern "C"
#else
#define PREF1
#endif

#ifdef WIN32
#define PREF2 __declspec(dllexport) __stdcall//pascal
#define MAX_TH03_UNITS          20

#elif defined(WINDOWS)
#define PREF2 _export pascal
#define MAX_TH03_UNITS          9

#elif defined (DOS)
#define PREF2 far pascal
#define MAX_TH03_UNITS          4

#else
#error Operating system not defined
#endif

#define MAX_TH03_CHANNELS	3
#define MAX_TH03_SENSOR_TYPES	7

	/* th03_get_driver_version
	 *
	 * Call this routine to check that the driver version is
	 * more recent than the version your program was designed to
	 * work with
	 *
	 * accepts:
	 *     nothing
	 *
	 * returns:
	 *     high byte: major version
	 *     low byte: minor version
	 *
	 */
 PREF1 short PREF2  th03_get_driver_version (void);


#if defined(WINDOWS) || defined(WIN32)
        /* th03_open_unit
         *
         * Call this routine once for each port that is connected to a TH-03
         *
         * accepts:
         *     port - COM port (1..10)
         *
         */
PREF1 short PREF2 th03_open_unit
                (
        short port
        );

#else
        /* th03_driver_open
	 *
         * Call this routine once for each port that is connected to a TH-03
         *
         * accepts:
         *     port - COM port (1..10)
         *     base - base address (for com1..com4, you can use 0 for default)
         *     irq  - interrupt (0..15) (for com1..com4, you can use 0 for default)
         */
PREF1 short PREF2 th03_open_unit
        (
        short    port,
        short    base,
        short    irq
        );
#endif


        /* th03_close_unit
         *
         * Call this routine once for each port that was opened
         *
         */
PREF1 void PREF2 th03_close_unit
        (
        short port
        );


        /* th03_poll
         *
                 * Call this routine periodically
         *  (normally only necessary under Windows... try without first)
         *
         */
PREF1 void PREF2 th03_poll_driver
        (
        void
        );


                                /* th03_set_channel
                                 *
                                 * Set the thermistor type and filter factor
                                 *
                                 * sensor_type       = 0 - off
				 *                     1 - EL015 temp (30k)
                                 *		       2 - medium temp (100k)
                                 *                     3 - high temp (1.2M)
                                 *                     4 - light sensor
				 *                     5 - door switch
                                 *		       6 - Unicam
				 *		       7 - EL039 temp
				 * filter_factor = 1 for fast update
                                 *                 10 for normal update
                                 *                 250 for exceedingly slow update
                                                                  */

PREF1 short PREF2 th03_set_channel
                (
                unsigned short port,
                unsigned short channel,
                unsigned short sensor_type,
                unsigned short filter_factor);

                                /* th03_set_ret_update
                                 *
                                 * Set the number of measurements per ref update
                                 *
                                 * set to 10 for normal operation
                                 * set to 1 for even sampling intervals
                                 * set to 0 to turn off temporarily
                 */


        PREF1 short PREF2 th03_set_ref_update (unsigned short port,
                                                unsigned short update_interval);

                                /* th03_set_quick_convert
                                 *
                                 * Set the number of measurements per ref update
                                 *
                                 * set to 10 for normal operation
                                 * set to 1 for even sampling intervals
                                 * set to 0 to turn off temporarily
                 */


        PREF1 short PREF2 th03_set_quick_convert (unsigned short port,
                                                unsigned short quick);

        /* th03_get_temp
         *
         * This routine gets the most recent reading from the adc
         *
         */
PREF1 short  PREF2 th03_get_temp
        (
        long /*far*/ *      temp,
        unsigned short    port,
        unsigned short    channel,
        short             filtered

        );

        /* th03_get_version
         *
         * This routine gets the TH03 version
         *
         */
PREF1 short  PREF2 th03_get_version
        (
        unsigned short /*far*/ *      version,
        unsigned short           port
        );

	/* th03_get_ref
	 *
	 * This routine is for test purposes only
	 *
	 */
PREF1 short  PREF2 th03_get_ref
	(
	unsigned short /*far*/ *      ref_low,
	unsigned short /*far*/ *      ref_high,
  	unsigned short            port
	);

	/* th03_update_filters
         *
         * This routine re-initialises the filters for all active channels
         *
         */

PREF1 void  PREF2 th03_update_filters
        (
        void
        );

        /* th03_get_cycle
         *
	 * This routine gets the current measurement cycle:
         *  this increases each time a complete set of readings is taken
         */

PREF1 short  PREF2 th03_get_cycle
        (
        unsigned long /*far*/ * cycle,
        unsigned short port
        );



